@@ -80,8 +80,8 @@ class Blather():
                 if step == 0:
                     start = time.time()
                 if step == 1:
-                    total_time_estimate = (time.time()-start) * (total_steps-1)
-                    print("Training Time estimate is : " + str(total_time_estimate))
+                    total_time_estimate = round((time.time()-start) * (total_steps-1)/60)
+                    print("Estimated Training time of " + str(total_time_estimate) + " minutes ")
                 b_input_ids = batch[0].to(self.device)
                 b_labels = batch[0].to(self.device)
                 b_masks = batch[1].to(self.device)
